@@ -416,7 +416,7 @@ def pyrogram_api():
                     title = "{}".format(type)
 
                     f2.write(title + "\n" + "=" * len(title) + "\n\n")
-                    f2.write(".. autoclass:: pyrogram.types.{}()".format(type))
+                    f2.write(".. autoclass:: pyrogram.types.{}()\n".format(type))
 
         f.write(template.format(**fmt_keys))
 
